/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus;

import java.io.ByteArrayInputStream;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Unmarshaller;
import nl.cloudfarming.client.isobus.model.Isobus;
import nl.cloudfarming.client.logging.AppLogFactory;
import nl.cloudfarming.client.logging.AppLogger;

/**
 * Marshaller to unmarshall iso 11783-10 messages
 * @author Merijn Zengers
 */
public class IsobusMarshaller {
    private static final AppLogger LOG = AppLogFactory.getLogger(IsobusMarshaller.class);
    private final String PACKAGE_NAME = "nl.cloudfarming.client.isobus.model";
    
    
    /**
     * Unmarshal String containing xml to an Isobus object
     * @param XML the String to unmarshall
     * @return An Isobus object
     */
    public Isobus unMarshall(String XML){
        JAXBContext jc;
        Isobus created = null;
        try {
            jc = JAXBContext.newInstance(PACKAGE_NAME);
            Unmarshaller unmarshaller =jc.createUnmarshaller();
            ByteArrayInputStream in = new ByteArrayInputStream(XML.getBytes());
            
            created = (Isobus) unmarshaller.unmarshal(in);
        } catch (JAXBException ex) {
            LOG.error("Failed to convert xml", ex);
        }
        return created;
    }
}
