/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.isobus;

import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.isobus.model.Isobus;
import nl.cloudfarming.client.isobus.model.Partfield;
import nl.cloudfarming.client.model.CommonModelService;
import org.openide.util.lookup.ServiceProvider;

/**
 * Implementation of IsobusService.
 * Provides methods to get model components out of a XML or Isobus rootElement
 * @author Merijn Zengers
 */
@ServiceProvider(service = IsobusService.class)
public final class IsobusServiceImpl extends CommonModelService implements IsobusService{
    
    @Override
    protected String getModuleName() {
        return IsobusModule.MODULE_NAME;
    }

    @Override
    protected void initExplorer() {
    }

    /**
     * Build list of Agrosense Partfields from this isobus task
     * @param isobus
     * @return 
     */
    
    @Override
    public List<nl.cloudfarming.client.model.PartField> getPartFields(Isobus isobus) {
        List<nl.cloudfarming.client.model.PartField> partFields = new ArrayList<nl.cloudfarming.client.model.PartField>();
        for(Partfield partField : isobus.getPFD()){
            String partFieldId = partField.getId().replace("PFD", "").replace("-", "");
            nl.cloudfarming.client.model.PartField found = getPartFieldById(Integer.parseInt(partFieldId));
            if(found == null){
                throw new UnsupportedOperationException("PartField not found, must be available in system");
            }
            partFields.add(found);
        }
        return partFields;
    }
    
    @Override
    public nl.cloudfarming.client.model.PartField getPartFieldById(long id){
        return getEntityManager().find(nl.cloudfarming.client.model.PartField.class, id);
    }     
        

    
    
}
